@@ -66,7 +66,7 @@ fi
 # set defaults, if nothing given
 [ "${KERNEL}" = "" ] && KERNEL=$(uname -r)
 [ "${LTS_KERNEL}" = "" ] && LTS_KERNEL="2.6.32-lts"
-[ "${RELEASENAME}" = "" ] && RELEASENAME="2k10-R4"
+[ "${RELEASENAME}" = "" ] && RELEASENAME="2k10-R5"
 [ "${IMAGENAME}" = "" ] && IMAGENAME="Archlinux-allinone-$(date +%Y.%m)"
 
 # generate temp directories
@@ -121,7 +121,13 @@ mv ${CORE64_LTS}/tmp/*/isolinux/initrd.img ${ALLINONE}/isolinux/initrd64lts.img
 mv ${CORE}/tmp/*/isolinux/isolinux.cfg ${ALLINONE}/isolinux/
 mv ${CORE}/tmp/*/isolinux/boot.msg ${ALLINONE}/isolinux/
 mv ${CORE}/tmp/*/isolinux/options.msg ${ALLINONE}/isolinux/
+# place syslinux files
 mv ${CORE}/tmp/*/isolinux/isolinux.bin ${ALLINONE}/isolinux/
+mv ${CORE}/tmp/*/isolinux/*.c32 ${ALLINONE}/isolinux/
+mv ${CORE}/tmp/*/isolinux/pci.ids ${ALLINONE}/isolinux/
+mv ${CORE}/tmp/*/isolinux/modules.pcimap ${ALLINONE}/isolinux/
+mv ${CORE}/tmp/*/isolinux/splash.png ${ALLINONE}/isolinux/
+
 # Change parameters in boot.msg
 sed -i -e "s/@@DATE@@/$(date)/g" -e "s/@@KERNEL@@/$KERNEL/g"  -e "s/@@LTS_KERNEL@@/$LTS_KERNEL/g" -e "s/@@RELEASENAME@@/$RELEASENAME/g" -e "s/@@BOOTLOADER@@/ISOLINUX/g" ${ALLINONE}/isolinux/boot.msg
 
